@@ -22,11 +22,11 @@ else:
 
 __all__ = (
     "CreateTokenRequestRequestTypeDef",
-    "CreateTokenResponseTypeDef",
-    "RegisterClientRequestRequestTypeDef",
-    "RegisterClientResponseTypeDef",
     "ResponseMetadataTypeDef",
+    "RegisterClientRequestRequestTypeDef",
     "StartDeviceAuthorizationRequestRequestTypeDef",
+    "CreateTokenResponseTypeDef",
+    "RegisterClientResponseTypeDef",
     "StartDeviceAuthorizationResponseTypeDef",
 )
 
@@ -57,15 +57,14 @@ class CreateTokenRequestRequestTypeDef(
     pass
 
 
-CreateTokenResponseTypeDef = TypedDict(
-    "CreateTokenResponseTypeDef",
+ResponseMetadataTypeDef = TypedDict(
+    "ResponseMetadataTypeDef",
     {
-        "accessToken": str,
-        "tokenType": str,
-        "expiresIn": int,
-        "refreshToken": str,
-        "idToken": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
+        "RequestId": str,
+        "HostId": str,
+        "HTTPStatusCode": int,
+        "HTTPHeaders": Dict[str, str],
+        "RetryAttempts": int,
     },
 )
 
@@ -91,6 +90,27 @@ class RegisterClientRequestRequestTypeDef(
     pass
 
 
+StartDeviceAuthorizationRequestRequestTypeDef = TypedDict(
+    "StartDeviceAuthorizationRequestRequestTypeDef",
+    {
+        "clientId": str,
+        "clientSecret": str,
+        "startUrl": str,
+    },
+)
+
+CreateTokenResponseTypeDef = TypedDict(
+    "CreateTokenResponseTypeDef",
+    {
+        "accessToken": str,
+        "tokenType": str,
+        "expiresIn": int,
+        "refreshToken": str,
+        "idToken": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
 RegisterClientResponseTypeDef = TypedDict(
     "RegisterClientResponseTypeDef",
     {
@@ -100,27 +120,7 @@ RegisterClientResponseTypeDef = TypedDict(
         "clientSecretExpiresAt": int,
         "authorizationEndpoint": str,
         "tokenEndpoint": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-ResponseMetadataTypeDef = TypedDict(
-    "ResponseMetadataTypeDef",
-    {
-        "RequestId": str,
-        "HostId": str,
-        "HTTPStatusCode": int,
-        "HTTPHeaders": Dict[str, str],
-        "RetryAttempts": int,
-    },
-)
-
-StartDeviceAuthorizationRequestRequestTypeDef = TypedDict(
-    "StartDeviceAuthorizationRequestRequestTypeDef",
-    {
-        "clientId": str,
-        "clientSecret": str,
-        "startUrl": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
     },
 )
 
@@ -133,6 +133,6 @@ StartDeviceAuthorizationResponseTypeDef = TypedDict(
         "verificationUriComplete": str,
         "expiresIn": int,
         "interval": int,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
+        "ResponseMetadata": ResponseMetadataTypeDef,
     },
 )
